launch_with_args

Function launch_with_args 

pub async fn launch_with_args(args: AppArgs) -> Result<()>
Launches the application with the given arguments.

This function prepares the application environment and then runs either a client or a mailbox node, depending on the provided arguments.

Arguments

  • args - The command-line arguments to use.

Errors

This function will return an error if the application fails to launch.